#! /bin/tcsh
#To switch shell > exec /usr/bin/tcsh

@ iday = 1
set year_name  = "2017" #"2008"
set month_name = "06"

set name_start  = COSP_CAM5_f09.cam.h2. #for 2017 1 degree
#COSP_CAM5_t3_CFAD.cam.h2. for 2017 #COSP_CAM5_t3.cam.h2. for 2008
set name_ending = _LevRev.nc
set reff_name   = REFFonly_CAM5_1deg_all9together_

while ($iday <= 30)

  @ itime = 0
  
  if ($iday < 10) then
    set day_name = 0{$iday}
  else
    set day_name = {$iday}
  endif

  set filename = $name_start$year_name-$month_name-$day_name-03600
  echo filename, $filename
  
  #reverse levels since COSP needs surface-to-TOA
  ncpdq --rdr=-lev $filename.nc $filename$name_ending
  echo finished reversing levels

  ###Rename some variables to appropriate COSP names
  ncrename -v SNOW_CV_COSP,fl_ccsnow -v SNOW_LS_COSP,fl_lssnow -v GRPL_LS_COSP,fl_lsgrpl $filename$name_ending
  ncrename -v RAIN_CV_COSP,fl_ccrain -v RAIN_LS_COSP,fl_lsrain $filename$name_ending 
  ncrename -v P_COSP,pfull -v PH_COSP,phalf $filename$name_ending
  ncrename -v ZLEV_COSP,height -v ZLEV_HALF_COSP,height_half $filename$name_ending
  ncrename -v T_COSP,T_abs -v Q_COSP,qv $filename$name_ending
  ncrename -v LSCLIQ_COSP,mr_lsliq -v LSCICE_COSP,mr_lsice $filename$name_ending 
  ncrename -v CVCLIQ_COSP,mr_ccliq -v CVCICE_COSP,mr_ccice $filename$name_ending
  ncrename -v V_COSP,v_wind -v U_COSP,u_wind $filename$name_ending
  ncrename -v CLD_COSP,tca -v CONCLD_COSP,cca $filename$name_ending
  ncrename -v NRAIN,nc_lsrain -v NSNOW,nc_lssnow -v ICWNC,nc_lsliq -v ICINC,nc_lsice $filename$name_ending #number concentration
  
  ###Lev variable & dimension needs to be renamed to level
  ncrename -v lev,level -d lev,level $filename$name_ending
  echo finished renaming variables

  #***************************************************************************************************
  #Loop through each hour in the day
  @ ihour = 1 #this is reset for each day

  while ($ihour <= 24)

    if ($ihour == 24) then
       @ new_day = $iday + 1
       
       if ($new_day < 10) then
          set new_day_name = 0{$new_day}
       else
          set new_day_name = {$new_day}
       endif
      
       set date_name = $year_name-$month_name-$new_day_name-00

     else

       if ($ihour < 10) then
         set date_name = $year_name-$month_name-$day_name-0{$ihour}
       else
         set date_name = $year_name-$month_name-$day_name-{$ihour}
       endif
     
     endif 
    
    echo $date_name

    set hourly_file = CAM5_1deg_hrly.$date_name"_LevRev_ALLlats.nc"

    ###Extract single time dimension and put in separate file
    #Also need to eliminate time dimension since it now just has variables at one time.
    #ncwa averages over the dimension and thus removes it. In this case, since there's only one time there 
    #is effectively no averaging 
    ncks -d time,$itime $filename$name_ending $hourly_file
    ncwa -a time $hourly_file -O $hourly_file #removes time dimension, but not time var. Should I remove time var?

    #Extract single time dimension from effective radius file
    ncks -d time,$itime $reff_name$year_name-$month_name-$day_name.nc Reffs_$date_name.nc
    ncwa -a time Reffs_$date_name.nc -O Reffs_$date_name.nc
    
    echo finished extracting each time removing time dimension from $date_name

    #remove variables that have chars or slat as a dimension and those that are read in after last 2D variable is read in.
    #Having a 1D variable read in after the last 2D variable was read in was messing up Na value. 
    #Na needs to be 144 (i.e., number of lons),but was being reset to 38 when the 1D variabels w_stag and 
    #wnummax were being read in.
    #***Not needed for files grabbed from Mountain Scholar b/c I already removed the unneeded variables
    #ncks -C -x -v date_written,time_written,w_stag,slat,wnummax $hourly_file -O $hourly_file
    #echo finished removing some variables from $date_name

    #Append file with effective radius to hourly_file
    ncks -A Reffs_$date_name.nc $hourly_file
    
       @ ihour +=1   
       @ itime +=1

     end #end while $ihour loop

  @ iday +=1
end #while loop for iday
